[lld] 427b728 - [lld/ELF] Convert undef-spell-corrector.s test to split-file
Nico Weber via llvm-commits
llvm-commits at lists.llvm.org
Fri Oct 14 06:07:21 PDT 2022
Author: Nico Weber
Date: 2022-10-14T09:07:10-04:00
New Revision: 427b728834622dc879bca845def8d3d1c0108058
URL: https://github.com/llvm/llvm-project/commit/427b728834622dc879bca845def8d3d1c0108058
DIFF: https://github.com/llvm/llvm-project/commit/427b728834622dc879bca845def8d3d1c0108058.diff
LOG: [lld/ELF] Convert undef-spell-corrector.s test to split-file
Differential Revision: https://reviews.llvm.org/D135879
Added:
Modified:
lld/test/ELF/undef-spell-corrector.s
Removed:
################################################################################
diff --git a/lld/test/ELF/undef-spell-corrector.s b/lld/test/ELF/undef-spell-corrector.s
index 3ad2421a6cd63..264d685178daa 100644
--- a/lld/test/ELF/undef-spell-corrector.s
+++ b/lld/test/ELF/undef-spell-corrector.s
@@ -1,14 +1,23 @@
# REQUIRES: x86
-# RUN: llvm-mc -filetype=obj -triple=x86_64 %s -o %t.o
+
+# RUN: rm -rf %t && split-file %s %t
+# RUN: llvm-mc -filetype=obj -triple=x86_64 %t/test.s -o %t/test.o
+# RUN: llvm-mc -filetype=obj -triple=x86_64 %t/bcde-abcd-abde.s -o %t/bcde-abcd-abde.o
+# RUN: llvm-mc -filetype=obj -triple=x86_64 %t/bbcde-abcdd.s -o %t/bbcde-abcdd.o
+# RUN: llvm-mc -filetype=obj -triple=x86_64 %t/aabcde-abcdee.s -o %t/aabcde-abcdee.o
+# RUN: llvm-mc -filetype=obj -triple=x86_64 %t/bacde.s -o %t/bacde.o
+# RUN: llvm-mc -filetype=obj -triple=x86_64 %t/_Z3fooPi.s -o %t/_Z3fooPi.o
+# RUN: llvm-mc -filetype=obj -triple=x86_64 %t/_Z3fooPKi-_Z3fooPi.s -o %t/_Z3fooPKi-_Z3fooPi.o
+# RUN: llvm-mc -filetype=obj -triple=x86_64 %t/_Z3FOOPKi.s -o %t/_Z3FOOPKi.o
+# RUN: llvm-mc -filetype=obj -triple=x86_64 %t/_Z3fooPKi-_Z3FOOPKi.s -o %t/_Z3fooPKi-_Z3FOOPKi.o
## Insert a character.
## The spell corrector is enabled for the first two "undefined symbol" diagnostics.
-# RUN: echo 'call bcde; call abcd; call abde' | llvm-mc -filetype=obj -triple=x86_64 - -o %t1.o
-# RUN: not ld.lld %t.o %t1.o -o /dev/null 2>&1 | FileCheck --check-prefix=INSERT %s -DFILE=%t.o
+# RUN: not ld.lld %t/test.o %t/bcde-abcd-abde.o -o /dev/null 2>&1 | FileCheck --check-prefix=INSERT %s -DFILE=%t/test.o
## Symbols defined in DSO can be suggested.
# RUN: ld.lld %t.o -shared -o %t.so
# RUN: not ld.lld %t.so %t1.o -o /dev/null 2>&1 | FileCheck --check-prefix=INSERT %s -DFILE=%t.so
# INSERT: error: undefined symbol: bcde
# INSERT-NEXT: >>> referenced by {{.*}}
@@ -23,8 +32,7 @@
# INSERT-NOT: >>>
## Substitute a character.
-# RUN: echo 'call bbcde; call abcdd' | llvm-mc -filetype=obj -triple=x86_64 - -o %t1.o
-# RUN: not ld.lld %t.o %t1.o -o /dev/null 2>&1 | FileCheck --check-prefix=SUBST %s
+# RUN: not ld.lld %t/test.o %t/bbcde-abcdd.o -o /dev/null 2>&1 | FileCheck --check-prefix=SUBST %s
# SUBST: error: undefined symbol: bbcde
# SUBST-NEXT: >>> referenced by {{.*}}
@@ -34,8 +42,7 @@
# SUBST-NEXT: >>> did you mean: abcde
## Delete a character.
-# RUN: echo 'call aabcde; call abcdee' | llvm-mc -filetype=obj -triple=x86_64 - -o %t1.o
-# RUN: not ld.lld %t.o %t1.o -o /dev/null 2>&1 | FileCheck --check-prefix=DELETE %s
+# RUN: not ld.lld %t/test.o %t/aabcde-abcdee.o -o /dev/null 2>&1 | FileCheck --check-prefix=DELETE %s
# DELETE: error: undefined symbol: aabcde
# DELETE-NEXT: >>> referenced by {{.*}}
@@ -45,35 +52,59 @@
# DELETE-NEXT: >>> did you mean: abcde
## Transpose.
-# RUN: echo 'call bacde' | llvm-mc -filetype=obj -triple=x86_64 - -o %t1.o
-# RUN: not ld.lld %t.o %t1.o -o /dev/null 2>&1 | FileCheck --check-prefix=TRANSPOSE %s
+# RUN: not ld.lld %t/test.o %t/bacde.o -o /dev/null 2>&1 | FileCheck --check-prefix=TRANSPOSE %s
# TRANSPOSE: error: undefined symbol: bacde
# TRANSPOSE-NEXT: >>> referenced by {{.*}}
# TRANSPOSE-NEXT: >>> did you mean: abcde
## Missing const qualifier.
-# RUN: echo 'call _Z3fooPi' | llvm-mc -filetype=obj -triple=x86_64 - -o %t1.o
-# RUN: not ld.lld %t.o %t1.o -o /dev/null 2>&1 | FileCheck --check-prefix=CONST %s
+# RUN: not ld.lld %t/test.o %t/_Z3fooPi.o -o /dev/null 2>&1 | FileCheck --check-prefix=CONST %s
## Local defined symbols.
-# RUN: echo '_Z3fooPKi: call _Z3fooPi' | llvm-mc -filetype=obj -triple=x86_64 - -o %t1.o
-# RUN: not ld.lld %t1.o -o /dev/null 2>&1 | FileCheck --check-prefix=CONST %s
+# RUN: not ld.lld %t/_Z3fooPKi-_Z3fooPi.o -o /dev/null 2>&1 | FileCheck --check-prefix=CONST %s
# CONST: error: undefined symbol: foo(int*)
# CONST-NEXT: >>> referenced by {{.*}}
# CONST-NEXT: >>> did you mean: foo(int const*)
## Case mismatch.
-# RUN: echo 'call _Z3FOOPKi' | llvm-mc -filetype=obj -triple=x86_64 - -o %t1.o
-# RUN: not ld.lld %t.o %t1.o -o /dev/null 2>&1 | FileCheck --check-prefix=CASE %s
-# RUN: echo '_Z3fooPKi: call _Z3FOOPKi' | llvm-mc -filetype=obj -triple=x86_64 - -o %t1.o
-# RUN: not ld.lld %t1.o -o /dev/null 2>&1 | FileCheck --check-prefix=CASE %s
+# RUN: not ld.lld %t/test.o %t/_Z3FOOPKi.o -o /dev/null 2>&1 | FileCheck --check-prefix=CASE %s
+# RUN: not ld.lld %t/_Z3fooPKi-_Z3FOOPKi.o -o /dev/null 2>&1 | FileCheck --check-prefix=CASE %s
# CASE: error: undefined symbol: FOO(int const*)
# CASE-NEXT: >>> referenced by {{.*}}
# CASE-NEXT: >>> did you mean: foo(int const*)
+#--- test.s
.globl _start, abcde, _Z3fooPKi
_start:
abcde:
_Z3fooPKi:
+
+#--- bcde-abcd-abde.s
+call bcde
+call abcd
+call abde
+
+#--- bbcde-abcdd.s
+call bbcde
+call abcdd
+
+#--- aabcde-abcdee.s
+call aabcde
+call abcdee
+
+#--- bacde.s
+call bacde
+
+#--- _Z3fooPi.s
+call _Z3fooPi
+
+#--- _Z3fooPKi-_Z3fooPi.s
+_Z3fooPKi: call _Z3fooPi
+
+#--- _Z3FOOPKi.s
+call _Z3FOOPKi
+
+#--- _Z3fooPKi-_Z3FOOPKi.s
+_Z3fooPKi: call _Z3FOOPKi
More information about the llvm-commits
mailing list
@@ -1,14 +1,23 @@
## Symbols defined in DSO can be suggested.
-# RUN: ld.lld %t.o -shared -o %t.so
-# RUN: not ld.lld %t.so %t1.o -o /dev/null 2>&1 | FileCheck --check-prefix=INSERT %s -DFILE=%t.so
+# RUN: ld.lld %t/test.o -shared -o %t.so
+# RUN: not ld.lld %t.so %t/bcde-abcd-abde.o -o /dev/null 2>&1 | FileCheck --check-prefix=INSERT %s -DFILE=%t.so
# INSERT: error: undefined symbol: bcde
# INSERT-NEXT: >>> referenced by {{.*}}